use strict;

package ASCOPE::Article::Collection::NYTimes::Intl;
use base qw (Exporter);

# $Id: Intl.pm,v 1.2 2004/09/18 21:51:49 asc Exp $

=head1 NAME

ASCOPE::Article::Collection::NYTimes::Intl - Generaic international location functions for ASCOPE::Article::Collection::NYTimes

=head1 SYNOPSIS

 Ceci n'est pas une boite noire. Please use
 ASCOPE::Article::Collection::NYTimes
    
=head1 DESCRIPTION

Generaic international location functions for ASCOPE::Article::Collection::NYTimes.

=cut

use vars qw (@EXPORT);
@EXPORT    = qw(intlcity_latlong);

use WWW::Gazetteer;
use Locale::Country;

sub intlcity_latlong {
    my $city    = shift;
    my $country = shift;

    my $code = ($country =~ /^([A-Z][A-Z])$/) ? $1 : 
	uc(country2code($country, LOCALE_CODE_ALPHA_2));
    
    if (! $code) {
	warn "can't get code for $country\n";
	return undef;
    }

    my $g   = WWW::Gazetteer->new('heavensabove');
    my @loc = ();

    eval {

	# TO DO : wrap all of this up in a
	# convenient subroutine reference to
	# pass to grep 

	if (($city eq "Berlin") && ($code eq "DE")) {
	    @loc = grep {
		$_->{region} eq "Berlin";
	    } $g->find($city,$code);
	}

	elsif (($city eq "Dublin") && ($code eq "IE")) {
	    @loc = grep {
		$_->{region} eq "Dublin";
	    } $g->find($city,$code);
	}

	elsif (($city eq "Beijing") && ($code eq "CN")) {
	    @loc = grep {
		$_->{region} eq "Beijing";
	    } $g->find($city,$code);
	}

	elsif (($city eq "Shanghai") && ($code eq "CN")) {
	    @loc = grep {
		$_->{alias} eq "";
	    } $g->find($city,$code);
	}

	elsif (($city eq "Montreal") && ($code eq "CA")) {
	    @loc = grep {
		$_->{alias} eq "";
	    } $g->find($city,$code);
	}

	elsif (($city eq "Paris") && ($code eq "FR")) {
	    @loc = grep {
		# can't be bothered to remember
		# how to match a capital-I with
		# a little hat
		$_->{region} =~ /le-de-France$/;
	    } $g->find($city,$code);
	}

	elsif (($city eq "Mexico City") && ($code eq "MX")) {
	    @loc = grep {
		$_->{region} eq "Distrito Federal";
	    } $g->find("Mexico",$code);
	}

	elsif (($city eq "Hague") && ($code eq "NL")) {
	    @loc = $g->find("The $city", $code);
	}

	else {
	    @loc = $g->find($city, $code);
	}
    };

    if ($@) {
	warn "[$code] $@\n";
	return undef;
    }

    if (scalar(@loc) > 1) {
	warn "multiple results for $city $code\n";
	return undef;
    }

    #

    return ($loc[0]->{latitude},
	    $loc[0]->{longitude});
}

=head1 VERSION

1.0

=head1 DATE

$Date: 2004/09/18 21:51:49 $

=head1 AUTHOR

Aaron Straup Cope E<lt>ascope@cpan.orgE<gt>

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All rights reserved.

This is free software, you may use it and distribute it under
the same terms as Perl itself.

=cut

return 1;
